@@ -14,3 +14,8 @@ OBJECT_CLASSES = {
     resources.Wire.OBJECT_NAME: resources.Wire,
     resources.WireInstruction.OBJECT_NAME: resources.WireInstruction,
 }
+
+if hasattr(resources, "MockWirePayment"):
+    OBJECT_CLASSES.update(
+        {resources.MockWirePayment.OBJECT_NAME: resources.MockWirePayment}
+    )
